# coding: utf-8

"""
    TrueLayer Resource API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1.0
    Contact: rienafairefr@gmail.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

import marshmallow
from marshmallow import Schema, validates, ValidationError, post_load, missing

import truelayer
import truelayer.fields
from truelayer.configuration import Configuration


"""
CodegenModel{parent='null', parentSchema='null', interfaces=null, allParents=null, parentModel=null, interfaceModels=null, children=null, anyOf=[], oneOf=[], allOf=[], name='Balance', classname='Balance', title='Balance', description='null', classVarName='balance', modelJson='{
  "title" : "Balance",
  "type" : "object",
  "properties" : {
    "available" : {
      "title" : "available",
      "type" : "number",
      "format" : "float"
    },
    "currency" : {
      "title" : "currency",
      "type" : "string"
    },
    "current" : {
      "title" : "current",
      "type" : "number",
      "format" : "float"
    },
    "update_timestamp" : {
      "title" : "update_timestamp",
      "type" : "string",
      "format" : "date-time"
    }
  },
  "example" : {
    "current" : 6.027456183070403,
    "update_timestamp" : "2000-01-23T04:56:07.000+00:00",
    "available" : 0.8008281904610115,
    "currency" : "currency"
  }
}', dataType='object', xmlPrefix='null', xmlNamespace='null', xmlName='null', classFilename='balance', unescapedDescription='null', discriminator=null, defaultValue='null', arrayModelType='null', isAlias=false, isString=false, isInteger=false, isLong=false, isNumber=false, isNumeric=false, isFloat=false, isDouble=false, vars=[CodegenProperty{openApiType='number', baseName='available', complexType='null', getter='getAvailable', setter='setAvailable', description='null', dataType='float', datatypeWithEnum='float', dataFormat='float', name='available', min='null', max='null', defaultValue='null', defaultValueWithParam=' = data.available;', baseType='float', containerType='null', title='available', unescapedDescription='null', maxLength=null, minLength=null, pattern='null', example='1.337', jsonSchema='{
  "title" : "available",
  "type" : "number",
  "format" : "float"
}', minimum='null', maximum='null', exclusiveMinimum=false, exclusiveMaximum=false, hasMore=true, required=false, deprecated=false, secondaryParam=false, hasMoreNonReadOnly=false, isPrimitiveType=true, isModel=false, isContainer=false, isString=false, isNumeric=true, isInteger=false, isLong=false, isNumber=false, isFloat=true, isDouble=false, isByteArray=false, isBinary=false, isFile=false, isBoolean=false, isDate=false, isDateTime=false, isUuid=false, isUri=false, isEmail=false, isFreeFormObject=false, isListContainer=false, isMapContainer=false, isEnum=false, isReadOnly=false, isWriteOnly=false, isNullable=false, isSelfReference=false, isCircularReference=false, _enum=null, allowableValues=null, items=null, mostInnerItems=null, vendorExtensions={}, hasValidation=false, isInherited=false, discriminatorValue='null', nameInCamelCase='Available', nameInSnakeCase='AVAILABLE', enumName='null', maxItems=null, minItems=null, maxProperties=null, minProperties=null, uniqueItems=false, multipleOf=null, isXmlAttribute=false, xmlPrefix='null', xmlName='null', xmlNamespace='null', isXmlWrapped=false}, CodegenProperty{openApiType='string', baseName='currency', complexType='null', getter='getCurrency', setter='setCurrency', description='null', dataType='str', datatypeWithEnum='str', dataFormat='null', name='currency', min='null', max='null', defaultValue='null', defaultValueWithParam=' = data.currency;', baseType='str', containerType='null', title='currency', unescapedDescription='null', maxLength=null, minLength=null, pattern='null', example=''0'', jsonSchema='{
  "title" : "currency",
  "type" : "string"
}', minimum='null', maximum='null', exclusiveMinimum=false, exclusiveMaximum=false, hasMore=true, required=false, deprecated=false, secondaryParam=false, hasMoreNonReadOnly=false, isPrimitiveType=true, isModel=false, isContainer=false, isString=true, isNumeric=false, isInteger=false, isLong=false, isNumber=false, isFloat=false, isDouble=false, isByteArray=false, isBinary=false, isFile=false, isBoolean=false, isDate=false, isDateTime=false, isUuid=false, isUri=false, isEmail=false, isFreeFormObject=false, isListContainer=false, isMapContainer=false, isEnum=false, isReadOnly=false, isWriteOnly=false, isNullable=false, isSelfReference=false, isCircularReference=false, _enum=null, allowableValues=null, items=null, mostInnerItems=null, vendorExtensions={}, hasValidation=false, isInherited=false, discriminatorValue='null', nameInCamelCase='Currency', nameInSnakeCase='CURRENCY', enumName='null', maxItems=null, minItems=null, maxProperties=null, minProperties=null, uniqueItems=false, multipleOf=null, isXmlAttribute=false, xmlPrefix='null', xmlName='null', xmlNamespace='null', isXmlWrapped=false}, CodegenProperty{openApiType='number', baseName='current', complexType='null', getter='getCurrent', setter='setCurrent', description='null', dataType='float', datatypeWithEnum='float', dataFormat='float', name='current', min='null', max='null', defaultValue='null', defaultValueWithParam=' = data.current;', baseType='float', containerType='null', title='current', unescapedDescription='null', maxLength=null, minLength=null, pattern='null', example='1.337', jsonSchema='{
  "title" : "current",
  "type" : "number",
  "format" : "float"
}', minimum='null', maximum='null', exclusiveMinimum=false, exclusiveMaximum=false, hasMore=true, required=false, deprecated=false, secondaryParam=false, hasMoreNonReadOnly=false, isPrimitiveType=true, isModel=false, isContainer=false, isString=false, isNumeric=true, isInteger=false, isLong=false, isNumber=false, isFloat=true, isDouble=false, isByteArray=false, isBinary=false, isFile=false, isBoolean=false, isDate=false, isDateTime=false, isUuid=false, isUri=false, isEmail=false, isFreeFormObject=false, isListContainer=false, isMapContainer=false, isEnum=false, isReadOnly=false, isWriteOnly=false, isNullable=false, isSelfReference=false, isCircularReference=false, _enum=null, allowableValues=null, items=null, mostInnerItems=null, vendorExtensions={}, hasValidation=false, isInherited=false, discriminatorValue='null', nameInCamelCase='Current', nameInSnakeCase='CURRENT', enumName='null', maxItems=null, minItems=null, maxProperties=null, minProperties=null, uniqueItems=false, multipleOf=null, isXmlAttribute=false, xmlPrefix='null', xmlName='null', xmlNamespace='null', isXmlWrapped=false}, CodegenProperty{openApiType='string', baseName='update_timestamp', complexType='null', getter='getUpdateTimestamp', setter='setUpdateTimestamp', description='null', dataType='datetime', datatypeWithEnum='datetime', dataFormat='date-time', name='update_timestamp', min='null', max='null', defaultValue='null', defaultValueWithParam=' = data.update_timestamp;', baseType='datetime', containerType='null', title='update_timestamp', unescapedDescription='null', maxLength=null, minLength=null, pattern='null', example='datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f')', jsonSchema='{
  "title" : "update_timestamp",
  "type" : "string",
  "format" : "date-time"
}', minimum='null', maximum='null', exclusiveMinimum=false, exclusiveMaximum=false, hasMore=false, required=false, deprecated=false, secondaryParam=false, hasMoreNonReadOnly=false, isPrimitiveType=true, isModel=false, isContainer=false, isString=false, isNumeric=false, isInteger=false, isLong=false, isNumber=false, isFloat=false, isDouble=false, isByteArray=false, isBinary=false, isFile=false, isBoolean=false, isDate=false, isDateTime=true, isUuid=false, isUri=false, isEmail=false, isFreeFormObject=false, isListContainer=false, isMapContainer=false, isEnum=false, isReadOnly=false, isWriteOnly=false, isNullable=false, isSelfReference=false, isCircularReference=false, _enum=null, allowableValues=null, items=null, mostInnerItems=null, vendorExtensions={}, hasValidation=false, isInherited=false, discriminatorValue='null', nameInCamelCase='UpdateTimestamp', nameInSnakeCase='UPDATE_TIMESTAMP', enumName='null', maxItems=null, minItems=null, maxProperties=null, minProperties=null, uniqueItems=false, multipleOf=null, isXmlAttribute=false, xmlPrefix='null', xmlName='null', xmlNamespace='null', isXmlWrapped=false}], allVars=[CodegenProperty{openApiType='number', baseName='available', complexType='null', getter='getAvailable', setter='setAvailable', description='null', dataType='float', datatypeWithEnum='float', dataFormat='float', name='available', min='null', max='null', defaultValue='null', defaultValueWithParam=' = data.available;', baseType='float', containerType='null', title='available', unescapedDescription='null', maxLength=null, minLength=null, pattern='null', example='1.337', jsonSchema='{
  "title" : "available",
  "type" : "number",
  "format" : "float"
}', minimum='null', maximum='null', exclusiveMinimum=false, exclusiveMaximum=false, hasMore=true, required=false, deprecated=false, secondaryParam=false, hasMoreNonReadOnly=false, isPrimitiveType=true, isModel=false, isContainer=false, isString=false, isNumeric=true, isInteger=false, isLong=false, isNumber=false, isFloat=true, isDouble=false, isByteArray=false, isBinary=false, isFile=false, isBoolean=false, isDate=false, isDateTime=false, isUuid=false, isUri=false, isEmail=false, isFreeFormObject=false, isListContainer=false, isMapContainer=false, isEnum=false, isReadOnly=false, isWriteOnly=false, isNullable=false, isSelfReference=false, isCircularReference=false, _enum=null, allowableValues=null, items=null, mostInnerItems=null, vendorExtensions={}, hasValidation=false, isInherited=false, discriminatorValue='null', nameInCamelCase='Available', nameInSnakeCase='AVAILABLE', enumName='null', maxItems=null, minItems=null, maxProperties=null, minProperties=null, uniqueItems=false, multipleOf=null, isXmlAttribute=false, xmlPrefix='null', xmlName='null', xmlNamespace='null', isXmlWrapped=false}, CodegenProperty{openApiType='string', baseName='currency', complexType='null', getter='getCurrency', setter='setCurrency', description='null', dataType='str', datatypeWithEnum='str', dataFormat='null', name='currency', min='null', max='null', defaultValue='null', defaultValueWithParam=' = data.currency;', baseType='str', containerType='null', title='currency', unescapedDescription='null', maxLength=null, minLength=null, pattern='null', example=''0'', jsonSchema='{
  "title" : "currency",
  "type" : "string"
}', minimum='null', maximum='null', exclusiveMinimum=false, exclusiveMaximum=false, hasMore=true, required=false, deprecated=false, secondaryParam=false, hasMoreNonReadOnly=false, isPrimitiveType=true, isModel=false, isContainer=false, isString=true, isNumeric=false, isInteger=false, isLong=false, isNumber=false, isFloat=false, isDouble=false, isByteArray=false, isBinary=false, isFile=false, isBoolean=false, isDate=false, isDateTime=false, isUuid=false, isUri=false, isEmail=false, isFreeFormObject=false, isListContainer=false, isMapContainer=false, isEnum=false, isReadOnly=false, isWriteOnly=false, isNullable=false, isSelfReference=false, isCircularReference=false, _enum=null, allowableValues=null, items=null, mostInnerItems=null, vendorExtensions={}, hasValidation=false, isInherited=false, discriminatorValue='null', nameInCamelCase='Currency', nameInSnakeCase='CURRENCY', enumName='null', maxItems=null, minItems=null, maxProperties=null, minProperties=null, uniqueItems=false, multipleOf=null, isXmlAttribute=false, xmlPrefix='null', xmlName='null', xmlNamespace='null', isXmlWrapped=false}, CodegenProperty{openApiType='number', baseName='current', complexType='null', getter='getCurrent', setter='setCurrent', description='null', dataType='float', datatypeWithEnum='float', dataFormat='float', name='current', min='null', max='null', defaultValue='null', defaultValueWithParam=' = data.current;', baseType='float', containerType='null', title='current', unescapedDescription='null', maxLength=null, minLength=null, pattern='null', example='1.337', jsonSchema='{
  "title" : "current",
  "type" : "number",
  "format" : "float"
}', minimum='null', maximum='null', exclusiveMinimum=false, exclusiveMaximum=false, hasMore=true, required=false, deprecated=false, secondaryParam=false, hasMoreNonReadOnly=false, isPrimitiveType=true, isModel=false, isContainer=false, isString=false, isNumeric=true, isInteger=false, isLong=false, isNumber=false, isFloat=true, isDouble=false, isByteArray=false, isBinary=false, isFile=false, isBoolean=false, isDate=false, isDateTime=false, isUuid=false, isUri=false, isEmail=false, isFreeFormObject=false, isListContainer=false, isMapContainer=false, isEnum=false, isReadOnly=false, isWriteOnly=false, isNullable=false, isSelfReference=false, isCircularReference=false, _enum=null, allowableValues=null, items=null, mostInnerItems=null, vendorExtensions={}, hasValidation=false, isInherited=false, discriminatorValue='null', nameInCamelCase='Current', nameInSnakeCase='CURRENT', enumName='null', maxItems=null, minItems=null, maxProperties=null, minProperties=null, uniqueItems=false, multipleOf=null, isXmlAttribute=false, xmlPrefix='null', xmlName='null', xmlNamespace='null', isXmlWrapped=false}, CodegenProperty{openApiType='string', baseName='update_timestamp', complexType='null', getter='getUpdateTimestamp', setter='setUpdateTimestamp', description='null', dataType='datetime', datatypeWithEnum='datetime', dataFormat='date-time', name='update_timestamp', min='null', max='null', defaultValue='null', defaultValueWithParam=' = data.update_timestamp;', baseType='datetime', containerType='null', title='update_timestamp', unescapedDescription='null', maxLength=null, minLength=null, pattern='null', example='datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f')', jsonSchema='{
  "title" : "update_timestamp",
  "type" : "string",
  "format" : "date-time"
}', minimum='null', maximum='null', exclusiveMinimum=false, exclusiveMaximum=false, hasMore=false, required=false, deprecated=false, secondaryParam=false, hasMoreNonReadOnly=false, isPrimitiveType=true, isModel=false, isContainer=false, isString=false, isNumeric=false, isInteger=false, isLong=false, isNumber=false, isFloat=false, isDouble=false, isByteArray=false, isBinary=false, isFile=false, isBoolean=false, isDate=false, isDateTime=true, isUuid=false, isUri=false, isEmail=false, isFreeFormObject=false, isListContainer=false, isMapContainer=false, isEnum=false, isReadOnly=false, isWriteOnly=false, isNullable=false, isSelfReference=false, isCircularReference=false, _enum=null, allowableValues=null, items=null, mostInnerItems=null, vendorExtensions={}, hasValidation=false, isInherited=false, discriminatorValue='null', nameInCamelCase='UpdateTimestamp', nameInSnakeCase='UPDATE_TIMESTAMP', enumName='null', maxItems=null, minItems=null, maxProperties=null, minProperties=null, uniqueItems=false, multipleOf=null, isXmlAttribute=false, xmlPrefix='null', xmlName='null', xmlNamespace='null', isXmlWrapped=false}], requiredVars=[], optionalVars=[CodegenProperty{openApiType='number', baseName='available', complexType='null', getter='getAvailable', setter='setAvailable', description='null', dataType='float', datatypeWithEnum='float', dataFormat='float', name='available', min='null', max='null', defaultValue='null', defaultValueWithParam=' = data.available;', baseType='float', containerType='null', title='available', unescapedDescription='null', maxLength=null, minLength=null, pattern='null', example='1.337', jsonSchema='{
  "title" : "available",
  "type" : "number",
  "format" : "float"
}', minimum='null', maximum='null', exclusiveMinimum=false, exclusiveMaximum=false, hasMore=true, required=false, deprecated=false, secondaryParam=false, hasMoreNonReadOnly=false, isPrimitiveType=true, isModel=false, isContainer=false, isString=false, isNumeric=true, isInteger=false, isLong=false, isNumber=false, isFloat=true, isDouble=false, isByteArray=false, isBinary=false, isFile=false, isBoolean=false, isDate=false, isDateTime=false, isUuid=false, isUri=false, isEmail=false, isFreeFormObject=false, isListContainer=false, isMapContainer=false, isEnum=false, isReadOnly=false, isWriteOnly=false, isNullable=false, isSelfReference=false, isCircularReference=false, _enum=null, allowableValues=null, items=null, mostInnerItems=null, vendorExtensions={}, hasValidation=false, isInherited=false, discriminatorValue='null', nameInCamelCase='Available', nameInSnakeCase='AVAILABLE', enumName='null', maxItems=null, minItems=null, maxProperties=null, minProperties=null, uniqueItems=false, multipleOf=null, isXmlAttribute=false, xmlPrefix='null', xmlName='null', xmlNamespace='null', isXmlWrapped=false}, CodegenProperty{openApiType='string', baseName='currency', complexType='null', getter='getCurrency', setter='setCurrency', description='null', dataType='str', datatypeWithEnum='str', dataFormat='null', name='currency', min='null', max='null', defaultValue='null', defaultValueWithParam=' = data.currency;', baseType='str', containerType='null', title='currency', unescapedDescription='null', maxLength=null, minLength=null, pattern='null', example=''0'', jsonSchema='{
  "title" : "currency",
  "type" : "string"
}', minimum='null', maximum='null', exclusiveMinimum=false, exclusiveMaximum=false, hasMore=true, required=false, deprecated=false, secondaryParam=false, hasMoreNonReadOnly=false, isPrimitiveType=true, isModel=false, isContainer=false, isString=true, isNumeric=false, isInteger=false, isLong=false, isNumber=false, isFloat=false, isDouble=false, isByteArray=false, isBinary=false, isFile=false, isBoolean=false, isDate=false, isDateTime=false, isUuid=false, isUri=false, isEmail=false, isFreeFormObject=false, isListContainer=false, isMapContainer=false, isEnum=false, isReadOnly=false, isWriteOnly=false, isNullable=false, isSelfReference=false, isCircularReference=false, _enum=null, allowableValues=null, items=null, mostInnerItems=null, vendorExtensions={}, hasValidation=false, isInherited=false, discriminatorValue='null', nameInCamelCase='Currency', nameInSnakeCase='CURRENCY', enumName='null', maxItems=null, minItems=null, maxProperties=null, minProperties=null, uniqueItems=false, multipleOf=null, isXmlAttribute=false, xmlPrefix='null', xmlName='null', xmlNamespace='null', isXmlWrapped=false}, CodegenProperty{openApiType='number', baseName='current', complexType='null', getter='getCurrent', setter='setCurrent', description='null', dataType='float', datatypeWithEnum='float', dataFormat='float', name='current', min='null', max='null', defaultValue='null', defaultValueWithParam=' = data.current;', baseType='float', containerType='null', title='current', unescapedDescription='null', maxLength=null, minLength=null, pattern='null', example='1.337', jsonSchema='{
  "title" : "current",
  "type" : "number",
  "format" : "float"
}', minimum='null', maximum='null', exclusiveMinimum=false, exclusiveMaximum=false, hasMore=true, required=false, deprecated=false, secondaryParam=false, hasMoreNonReadOnly=false, isPrimitiveType=true, isModel=false, isContainer=false, isString=false, isNumeric=true, isInteger=false, isLong=false, isNumber=false, isFloat=true, isDouble=false, isByteArray=false, isBinary=false, isFile=false, isBoolean=false, isDate=false, isDateTime=false, isUuid=false, isUri=false, isEmail=false, isFreeFormObject=false, isListContainer=false, isMapContainer=false, isEnum=false, isReadOnly=false, isWriteOnly=false, isNullable=false, isSelfReference=false, isCircularReference=false, _enum=null, allowableValues=null, items=null, mostInnerItems=null, vendorExtensions={}, hasValidation=false, isInherited=false, discriminatorValue='null', nameInCamelCase='Current', nameInSnakeCase='CURRENT', enumName='null', maxItems=null, minItems=null, maxProperties=null, minProperties=null, uniqueItems=false, multipleOf=null, isXmlAttribute=false, xmlPrefix='null', xmlName='null', xmlNamespace='null', isXmlWrapped=false}, CodegenProperty{openApiType='string', baseName='update_timestamp', complexType='null', getter='getUpdateTimestamp', setter='setUpdateTimestamp', description='null', dataType='datetime', datatypeWithEnum='datetime', dataFormat='date-time', name='update_timestamp', min='null', max='null', defaultValue='null', defaultValueWithParam=' = data.update_timestamp;', baseType='datetime', containerType='null', title='update_timestamp', unescapedDescription='null', maxLength=null, minLength=null, pattern='null', example='datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f')', jsonSchema='{
  "title" : "update_timestamp",
  "type" : "string",
  "format" : "date-time"
}', minimum='null', maximum='null', exclusiveMinimum=false, exclusiveMaximum=false, hasMore=false, required=false, deprecated=false, secondaryParam=false, hasMoreNonReadOnly=false, isPrimitiveType=true, isModel=false, isContainer=false, isString=false, isNumeric=false, isInteger=false, isLong=false, isNumber=false, isFloat=false, isDouble=false, isByteArray=false, isBinary=false, isFile=false, isBoolean=false, isDate=false, isDateTime=true, isUuid=false, isUri=false, isEmail=false, isFreeFormObject=false, isListContainer=false, isMapContainer=false, isEnum=false, isReadOnly=false, isWriteOnly=false, isNullable=false, isSelfReference=false, isCircularReference=false, _enum=null, allowableValues=null, items=null, mostInnerItems=null, vendorExtensions={}, hasValidation=false, isInherited=false, discriminatorValue='null', nameInCamelCase='UpdateTimestamp', nameInSnakeCase='UPDATE_TIMESTAMP', enumName='null', maxItems=null, minItems=null, maxProperties=null, minProperties=null, uniqueItems=false, multipleOf=null, isXmlAttribute=false, xmlPrefix='null', xmlName='null', xmlNamespace='null', isXmlWrapped=false}], readOnlyVars=[], readWriteVars=[CodegenProperty{openApiType='number', baseName='available', complexType='null', getter='getAvailable', setter='setAvailable', description='null', dataType='float', datatypeWithEnum='float', dataFormat='float', name='available', min='null', max='null', defaultValue='null', defaultValueWithParam=' = data.available;', baseType='float', containerType='null', title='available', unescapedDescription='null', maxLength=null, minLength=null, pattern='null', example='1.337', jsonSchema='{
  "title" : "available",
  "type" : "number",
  "format" : "float"
}', minimum='null', maximum='null', exclusiveMinimum=false, exclusiveMaximum=false, hasMore=true, required=false, deprecated=false, secondaryParam=false, hasMoreNonReadOnly=false, isPrimitiveType=true, isModel=false, isContainer=false, isString=false, isNumeric=true, isInteger=false, isLong=false, isNumber=false, isFloat=true, isDouble=false, isByteArray=false, isBinary=false, isFile=false, isBoolean=false, isDate=false, isDateTime=false, isUuid=false, isUri=false, isEmail=false, isFreeFormObject=false, isListContainer=false, isMapContainer=false, isEnum=false, isReadOnly=false, isWriteOnly=false, isNullable=false, isSelfReference=false, isCircularReference=false, _enum=null, allowableValues=null, items=null, mostInnerItems=null, vendorExtensions={}, hasValidation=false, isInherited=false, discriminatorValue='null', nameInCamelCase='Available', nameInSnakeCase='AVAILABLE', enumName='null', maxItems=null, minItems=null, maxProperties=null, minProperties=null, uniqueItems=false, multipleOf=null, isXmlAttribute=false, xmlPrefix='null', xmlName='null', xmlNamespace='null', isXmlWrapped=false}, CodegenProperty{openApiType='string', baseName='currency', complexType='null', getter='getCurrency', setter='setCurrency', description='null', dataType='str', datatypeWithEnum='str', dataFormat='null', name='currency', min='null', max='null', defaultValue='null', defaultValueWithParam=' = data.currency;', baseType='str', containerType='null', title='currency', unescapedDescription='null', maxLength=null, minLength=null, pattern='null', example=''0'', jsonSchema='{
  "title" : "currency",
  "type" : "string"
}', minimum='null', maximum='null', exclusiveMinimum=false, exclusiveMaximum=false, hasMore=true, required=false, deprecated=false, secondaryParam=false, hasMoreNonReadOnly=false, isPrimitiveType=true, isModel=false, isContainer=false, isString=true, isNumeric=false, isInteger=false, isLong=false, isNumber=false, isFloat=false, isDouble=false, isByteArray=false, isBinary=false, isFile=false, isBoolean=false, isDate=false, isDateTime=false, isUuid=false, isUri=false, isEmail=false, isFreeFormObject=false, isListContainer=false, isMapContainer=false, isEnum=false, isReadOnly=false, isWriteOnly=false, isNullable=false, isSelfReference=false, isCircularReference=false, _enum=null, allowableValues=null, items=null, mostInnerItems=null, vendorExtensions={}, hasValidation=false, isInherited=false, discriminatorValue='null', nameInCamelCase='Currency', nameInSnakeCase='CURRENCY', enumName='null', maxItems=null, minItems=null, maxProperties=null, minProperties=null, uniqueItems=false, multipleOf=null, isXmlAttribute=false, xmlPrefix='null', xmlName='null', xmlNamespace='null', isXmlWrapped=false}, CodegenProperty{openApiType='number', baseName='current', complexType='null', getter='getCurrent', setter='setCurrent', description='null', dataType='float', datatypeWithEnum='float', dataFormat='float', name='current', min='null', max='null', defaultValue='null', defaultValueWithParam=' = data.current;', baseType='float', containerType='null', title='current', unescapedDescription='null', maxLength=null, minLength=null, pattern='null', example='1.337', jsonSchema='{
  "title" : "current",
  "type" : "number",
  "format" : "float"
}', minimum='null', maximum='null', exclusiveMinimum=false, exclusiveMaximum=false, hasMore=true, required=false, deprecated=false, secondaryParam=false, hasMoreNonReadOnly=false, isPrimitiveType=true, isModel=false, isContainer=false, isString=false, isNumeric=true, isInteger=false, isLong=false, isNumber=false, isFloat=true, isDouble=false, isByteArray=false, isBinary=false, isFile=false, isBoolean=false, isDate=false, isDateTime=false, isUuid=false, isUri=false, isEmail=false, isFreeFormObject=false, isListContainer=false, isMapContainer=false, isEnum=false, isReadOnly=false, isWriteOnly=false, isNullable=false, isSelfReference=false, isCircularReference=false, _enum=null, allowableValues=null, items=null, mostInnerItems=null, vendorExtensions={}, hasValidation=false, isInherited=false, discriminatorValue='null', nameInCamelCase='Current', nameInSnakeCase='CURRENT', enumName='null', maxItems=null, minItems=null, maxProperties=null, minProperties=null, uniqueItems=false, multipleOf=null, isXmlAttribute=false, xmlPrefix='null', xmlName='null', xmlNamespace='null', isXmlWrapped=false}, CodegenProperty{openApiType='string', baseName='update_timestamp', complexType='null', getter='getUpdateTimestamp', setter='setUpdateTimestamp', description='null', dataType='datetime', datatypeWithEnum='datetime', dataFormat='date-time', name='update_timestamp', min='null', max='null', defaultValue='null', defaultValueWithParam=' = data.update_timestamp;', baseType='datetime', containerType='null', title='update_timestamp', unescapedDescription='null', maxLength=null, minLength=null, pattern='null', example='datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f')', jsonSchema='{
  "title" : "update_timestamp",
  "type" : "string",
  "format" : "date-time"
}', minimum='null', maximum='null', exclusiveMinimum=false, exclusiveMaximum=false, hasMore=false, required=false, deprecated=false, secondaryParam=false, hasMoreNonReadOnly=false, isPrimitiveType=true, isModel=false, isContainer=false, isString=false, isNumeric=false, isInteger=false, isLong=false, isNumber=false, isFloat=false, isDouble=false, isByteArray=false, isBinary=false, isFile=false, isBoolean=false, isDate=false, isDateTime=true, isUuid=false, isUri=false, isEmail=false, isFreeFormObject=false, isListContainer=false, isMapContainer=false, isEnum=false, isReadOnly=false, isWriteOnly=false, isNullable=false, isSelfReference=false, isCircularReference=false, _enum=null, allowableValues=null, items=null, mostInnerItems=null, vendorExtensions={}, hasValidation=false, isInherited=false, discriminatorValue='null', nameInCamelCase='UpdateTimestamp', nameInSnakeCase='UPDATE_TIMESTAMP', enumName='null', maxItems=null, minItems=null, maxProperties=null, minProperties=null, uniqueItems=false, multipleOf=null, isXmlAttribute=false, xmlPrefix='null', xmlName='null', xmlNamespace='null', isXmlWrapped=false}], parentVars=[], allowableValues=null, mandatory=[], allMandatory=[], imports=[], hasVars=true, emptyVars=false, hasMoreModels=false, hasEnums=false, isEnum=false, isNullable=false, hasRequired=false, hasOptional=true, isArrayModel=false, hasChildren=false, isMapModel=false, hasOnlyReadOnly=false, externalDocumentation=null, vendorExtensions={}, additionalPropertiesType='null', maxProperties=null, minProperties=null, uniqueItems=false, maxItems=null, minItems=null, maxLength=null, minLength=null, exclusiveMinimum=false, exclusiveMaximum=false, minimum='null', maximum='null', pattern='null', multipleOf='null'}
"""


class BalanceSchema(Schema):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    available = marshmallow.fields.Float()

    currency = marshmallow.fields.String()

    current = marshmallow.fields.Float()

    update_timestamp = truelayer.fields.DateTime()

    @validates("available")
    def validates_available(self, available):
        pass

    @validates("currency")
    def validates_currency(self, currency):
        pass

    @validates("current")
    def validates_current(self, current):
        pass

    @validates("update_timestamp")
    def validates_update_timestamp(self, update_timestamp):
        pass

    @post_load
    def post_load(self, data, **kwargs):
        config = Configuration()
        config.client_side_validation = False
        return Balance(local_vars_configuration=config, **data)


class Balance(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'available': 'float',
        'currency': 'str',
        'current': 'float',
        'update_timestamp': 'datetime'
    }

    attribute_map = {
        'available': 'available',
        'currency': 'currency',
        'current': 'current',
        'update_timestamp': 'update_timestamp'
    }

    def __init__(self, available=missing, currency=missing, current=missing, update_timestamp=missing, local_vars_configuration=None):  # noqa: E501
        """Balance - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self.discriminator = None
        if self.local_vars_configuration.client_side_validation:
            validated = BalanceSchema().load({
                'available': available,
                'currency': currency,
                'current': current,
                'update_timestamp': update_timestamp
            })
            self.available = validated.available
            self.currency = validated.currency
            self.current = validated.current
            self.update_timestamp = validated.update_timestamp
        else:
            self.available = available
            self.currency = currency
            self.current = current
            self.update_timestamp = update_timestamp

    def to_dict(self):
        """Returns the model properties as a dict"""
        return BalanceSchema().dump(self)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Balance):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Balance):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    TrueLayer Authtentication

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

import marshmallow
from marshmallow import Schema, validates, ValidationError, post_load, missing

import truelayer.auth
import truelayer.auth.fields
from truelayer.auth.configuration import Configuration


"""
CodegenModel{parent='null', parentSchema='null', interfaces=null, allParents=null, parentModel=null, interfaceModels=null, children=null, anyOf=[], oneOf=[], allOf=[], name='TokenResponse', classname='TokenResponse', title='null', description='null', classVarName='token_response', modelJson='{
  "type" : "object",
  "properties" : {
    "access_token" : {
      "type" : "string"
    },
    "expires_in" : {
      "type" : "integer"
    },
    "token_type" : {
      "type" : "string",
      "default" : "Bearer"
    },
    "refresh_token" : {
      "type" : "string"
    }
  }
}', dataType='object', xmlPrefix='null', xmlNamespace='null', xmlName='null', classFilename='token_response', unescapedDescription='null', discriminator=null, defaultValue='null', arrayModelType='null', isAlias=false, isString=false, isInteger=false, isLong=false, isNumber=false, isNumeric=false, isFloat=false, isDouble=false, vars=[CodegenProperty{openApiType='string', baseName='access_token', complexType='null', getter='getAccessToken', setter='setAccessToken', description='null', dataType='str', datatypeWithEnum='str', dataFormat='null', name='access_token', min='null', max='null', defaultValue='null', defaultValueWithParam=' = data.access_token;', baseType='str', containerType='null', title='null', unescapedDescription='null', maxLength=null, minLength=null, pattern='null', example=''0'', jsonSchema='{
  "type" : "string"
}', minimum='null', maximum='null', exclusiveMinimum=false, exclusiveMaximum=false, hasMore=true, required=false, deprecated=false, secondaryParam=false, hasMoreNonReadOnly=false, isPrimitiveType=true, isModel=false, isContainer=false, isString=true, isNumeric=false, isInteger=false, isLong=false, isNumber=false, isFloat=false, isDouble=false, isByteArray=false, isBinary=false, isFile=false, isBoolean=false, isDate=false, isDateTime=false, isUuid=false, isUri=false, isEmail=false, isFreeFormObject=false, isListContainer=false, isMapContainer=false, isEnum=false, isReadOnly=false, isWriteOnly=false, isNullable=false, isSelfReference=false, isCircularReference=false, _enum=null, allowableValues=null, items=null, mostInnerItems=null, vendorExtensions={}, hasValidation=false, isInherited=false, discriminatorValue='null', nameInCamelCase='AccessToken', nameInSnakeCase='ACCESS_TOKEN', enumName='null', maxItems=null, minItems=null, maxProperties=null, minProperties=null, uniqueItems=false, multipleOf=null, isXmlAttribute=false, xmlPrefix='null', xmlName='null', xmlNamespace='null', isXmlWrapped=false}, CodegenProperty{openApiType='integer', baseName='expires_in', complexType='null', getter='getExpiresIn', setter='setExpiresIn', description='null', dataType='int', datatypeWithEnum='int', dataFormat='null', name='expires_in', min='null', max='null', defaultValue='null', defaultValueWithParam=' = data.expires_in;', baseType='int', containerType='null', title='null', unescapedDescription='null', maxLength=null, minLength=null, pattern='null', example='56', jsonSchema='{
  "type" : "integer"
}', minimum='null', maximum='null', exclusiveMinimum=false, exclusiveMaximum=false, hasMore=true, required=false, deprecated=false, secondaryParam=false, hasMoreNonReadOnly=false, isPrimitiveType=true, isModel=false, isContainer=false, isString=false, isNumeric=true, isInteger=true, isLong=false, isNumber=false, isFloat=false, isDouble=false, isByteArray=false, isBinary=false, isFile=false, isBoolean=false, isDate=false, isDateTime=false, isUuid=false, isUri=false, isEmail=false, isFreeFormObject=false, isListContainer=false, isMapContainer=false, isEnum=false, isReadOnly=false, isWriteOnly=false, isNullable=false, isSelfReference=false, isCircularReference=false, _enum=null, allowableValues=null, items=null, mostInnerItems=null, vendorExtensions={}, hasValidation=false, isInherited=false, discriminatorValue='null', nameInCamelCase='ExpiresIn', nameInSnakeCase='EXPIRES_IN', enumName='null', maxItems=null, minItems=null, maxProperties=null, minProperties=null, uniqueItems=false, multipleOf=null, isXmlAttribute=false, xmlPrefix='null', xmlName='null', xmlNamespace='null', isXmlWrapped=false}, CodegenProperty{openApiType='string', baseName='token_type', complexType='null', getter='getTokenType', setter='setTokenType', description='null', dataType='str', datatypeWithEnum='str', dataFormat='null', name='token_type', min='null', max='null', defaultValue=''Bearer'', defaultValueWithParam=' = data.token_type;', baseType='str', containerType='null', title='null', unescapedDescription='null', maxLength=null, minLength=null, pattern='null', example=''0'', jsonSchema='{
  "type" : "string",
  "default" : "Bearer"
}', minimum='null', maximum='null', exclusiveMinimum=false, exclusiveMaximum=false, hasMore=true, required=false, deprecated=false, secondaryParam=false, hasMoreNonReadOnly=false, isPrimitiveType=true, isModel=false, isContainer=false, isString=true, isNumeric=false, isInteger=false, isLong=false, isNumber=false, isFloat=false, isDouble=false, isByteArray=false, isBinary=false, isFile=false, isBoolean=false, isDate=false, isDateTime=false, isUuid=false, isUri=false, isEmail=false, isFreeFormObject=false, isListContainer=false, isMapContainer=false, isEnum=false, isReadOnly=false, isWriteOnly=false, isNullable=false, isSelfReference=false, isCircularReference=false, _enum=null, allowableValues=null, items=null, mostInnerItems=null, vendorExtensions={}, hasValidation=false, isInherited=false, discriminatorValue='null', nameInCamelCase='TokenType', nameInSnakeCase='TOKEN_TYPE', enumName='null', maxItems=null, minItems=null, maxProperties=null, minProperties=null, uniqueItems=false, multipleOf=null, isXmlAttribute=false, xmlPrefix='null', xmlName='null', xmlNamespace='null', isXmlWrapped=false}, CodegenProperty{openApiType='string', baseName='refresh_token', complexType='null', getter='getRefreshToken', setter='setRefreshToken', description='null', dataType='str', datatypeWithEnum='str', dataFormat='null', name='refresh_token', min='null', max='null', defaultValue='null', defaultValueWithParam=' = data.refresh_token;', baseType='str', containerType='null', title='null', unescapedDescription='null', maxLength=null, minLength=null, pattern='null', example=''0'', jsonSchema='{
  "type" : "string"
}', minimum='null', maximum='null', exclusiveMinimum=false, exclusiveMaximum=false, hasMore=false, required=false, deprecated=false, secondaryParam=false, hasMoreNonReadOnly=false, isPrimitiveType=true, isModel=false, isContainer=false, isString=true, isNumeric=false, isInteger=false, isLong=false, isNumber=false, isFloat=false, isDouble=false, isByteArray=false, isBinary=false, isFile=false, isBoolean=false, isDate=false, isDateTime=false, isUuid=false, isUri=false, isEmail=false, isFreeFormObject=false, isListContainer=false, isMapContainer=false, isEnum=false, isReadOnly=false, isWriteOnly=false, isNullable=false, isSelfReference=false, isCircularReference=false, _enum=null, allowableValues=null, items=null, mostInnerItems=null, vendorExtensions={}, hasValidation=false, isInherited=false, discriminatorValue='null', nameInCamelCase='RefreshToken', nameInSnakeCase='REFRESH_TOKEN', enumName='null', maxItems=null, minItems=null, maxProperties=null, minProperties=null, uniqueItems=false, multipleOf=null, isXmlAttribute=false, xmlPrefix='null', xmlName='null', xmlNamespace='null', isXmlWrapped=false}], allVars=[CodegenProperty{openApiType='string', baseName='access_token', complexType='null', getter='getAccessToken', setter='setAccessToken', description='null', dataType='str', datatypeWithEnum='str', dataFormat='null', name='access_token', min='null', max='null', defaultValue='null', defaultValueWithParam=' = data.access_token;', baseType='str', containerType='null', title='null', unescapedDescription='null', maxLength=null, minLength=null, pattern='null', example=''0'', jsonSchema='{
  "type" : "string"
}', minimum='null', maximum='null', exclusiveMinimum=false, exclusiveMaximum=false, hasMore=true, required=false, deprecated=false, secondaryParam=false, hasMoreNonReadOnly=false, isPrimitiveType=true, isModel=false, isContainer=false, isString=true, isNumeric=false, isInteger=false, isLong=false, isNumber=false, isFloat=false, isDouble=false, isByteArray=false, isBinary=false, isFile=false, isBoolean=false, isDate=false, isDateTime=false, isUuid=false, isUri=false, isEmail=false, isFreeFormObject=false, isListContainer=false, isMapContainer=false, isEnum=false, isReadOnly=false, isWriteOnly=false, isNullable=false, isSelfReference=false, isCircularReference=false, _enum=null, allowableValues=null, items=null, mostInnerItems=null, vendorExtensions={}, hasValidation=false, isInherited=false, discriminatorValue='null', nameInCamelCase='AccessToken', nameInSnakeCase='ACCESS_TOKEN', enumName='null', maxItems=null, minItems=null, maxProperties=null, minProperties=null, uniqueItems=false, multipleOf=null, isXmlAttribute=false, xmlPrefix='null', xmlName='null', xmlNamespace='null', isXmlWrapped=false}, CodegenProperty{openApiType='integer', baseName='expires_in', complexType='null', getter='getExpiresIn', setter='setExpiresIn', description='null', dataType='int', datatypeWithEnum='int', dataFormat='null', name='expires_in', min='null', max='null', defaultValue='null', defaultValueWithParam=' = data.expires_in;', baseType='int', containerType='null', title='null', unescapedDescription='null', maxLength=null, minLength=null, pattern='null', example='56', jsonSchema='{
  "type" : "integer"
}', minimum='null', maximum='null', exclusiveMinimum=false, exclusiveMaximum=false, hasMore=true, required=false, deprecated=false, secondaryParam=false, hasMoreNonReadOnly=false, isPrimitiveType=true, isModel=false, isContainer=false, isString=false, isNumeric=true, isInteger=true, isLong=false, isNumber=false, isFloat=false, isDouble=false, isByteArray=false, isBinary=false, isFile=false, isBoolean=false, isDate=false, isDateTime=false, isUuid=false, isUri=false, isEmail=false, isFreeFormObject=false, isListContainer=false, isMapContainer=false, isEnum=false, isReadOnly=false, isWriteOnly=false, isNullable=false, isSelfReference=false, isCircularReference=false, _enum=null, allowableValues=null, items=null, mostInnerItems=null, vendorExtensions={}, hasValidation=false, isInherited=false, discriminatorValue='null', nameInCamelCase='ExpiresIn', nameInSnakeCase='EXPIRES_IN', enumName='null', maxItems=null, minItems=null, maxProperties=null, minProperties=null, uniqueItems=false, multipleOf=null, isXmlAttribute=false, xmlPrefix='null', xmlName='null', xmlNamespace='null', isXmlWrapped=false}, CodegenProperty{openApiType='string', baseName='token_type', complexType='null', getter='getTokenType', setter='setTokenType', description='null', dataType='str', datatypeWithEnum='str', dataFormat='null', name='token_type', min='null', max='null', defaultValue=''Bearer'', defaultValueWithParam=' = data.token_type;', baseType='str', containerType='null', title='null', unescapedDescription='null', maxLength=null, minLength=null, pattern='null', example=''0'', jsonSchema='{
  "type" : "string",
  "default" : "Bearer"
}', minimum='null', maximum='null', exclusiveMinimum=false, exclusiveMaximum=false, hasMore=true, required=false, deprecated=false, secondaryParam=false, hasMoreNonReadOnly=false, isPrimitiveType=true, isModel=false, isContainer=false, isString=true, isNumeric=false, isInteger=false, isLong=false, isNumber=false, isFloat=false, isDouble=false, isByteArray=false, isBinary=false, isFile=false, isBoolean=false, isDate=false, isDateTime=false, isUuid=false, isUri=false, isEmail=false, isFreeFormObject=false, isListContainer=false, isMapContainer=false, isEnum=false, isReadOnly=false, isWriteOnly=false, isNullable=false, isSelfReference=false, isCircularReference=false, _enum=null, allowableValues=null, items=null, mostInnerItems=null, vendorExtensions={}, hasValidation=false, isInherited=false, discriminatorValue='null', nameInCamelCase='TokenType', nameInSnakeCase='TOKEN_TYPE', enumName='null', maxItems=null, minItems=null, maxProperties=null, minProperties=null, uniqueItems=false, multipleOf=null, isXmlAttribute=false, xmlPrefix='null', xmlName='null', xmlNamespace='null', isXmlWrapped=false}, CodegenProperty{openApiType='string', baseName='refresh_token', complexType='null', getter='getRefreshToken', setter='setRefreshToken', description='null', dataType='str', datatypeWithEnum='str', dataFormat='null', name='refresh_token', min='null', max='null', defaultValue='null', defaultValueWithParam=' = data.refresh_token;', baseType='str', containerType='null', title='null', unescapedDescription='null', maxLength=null, minLength=null, pattern='null', example=''0'', jsonSchema='{
  "type" : "string"
}', minimum='null', maximum='null', exclusiveMinimum=false, exclusiveMaximum=false, hasMore=false, required=false, deprecated=false, secondaryParam=false, hasMoreNonReadOnly=false, isPrimitiveType=true, isModel=false, isContainer=false, isString=true, isNumeric=false, isInteger=false, isLong=false, isNumber=false, isFloat=false, isDouble=false, isByteArray=false, isBinary=false, isFile=false, isBoolean=false, isDate=false, isDateTime=false, isUuid=false, isUri=false, isEmail=false, isFreeFormObject=false, isListContainer=false, isMapContainer=false, isEnum=false, isReadOnly=false, isWriteOnly=false, isNullable=false, isSelfReference=false, isCircularReference=false, _enum=null, allowableValues=null, items=null, mostInnerItems=null, vendorExtensions={}, hasValidation=false, isInherited=false, discriminatorValue='null', nameInCamelCase='RefreshToken', nameInSnakeCase='REFRESH_TOKEN', enumName='null', maxItems=null, minItems=null, maxProperties=null, minProperties=null, uniqueItems=false, multipleOf=null, isXmlAttribute=false, xmlPrefix='null', xmlName='null', xmlNamespace='null', isXmlWrapped=false}], requiredVars=[], optionalVars=[CodegenProperty{openApiType='string', baseName='access_token', complexType='null', getter='getAccessToken', setter='setAccessToken', description='null', dataType='str', datatypeWithEnum='str', dataFormat='null', name='access_token', min='null', max='null', defaultValue='null', defaultValueWithParam=' = data.access_token;', baseType='str', containerType='null', title='null', unescapedDescription='null', maxLength=null, minLength=null, pattern='null', example=''0'', jsonSchema='{
  "type" : "string"
}', minimum='null', maximum='null', exclusiveMinimum=false, exclusiveMaximum=false, hasMore=true, required=false, deprecated=false, secondaryParam=false, hasMoreNonReadOnly=false, isPrimitiveType=true, isModel=false, isContainer=false, isString=true, isNumeric=false, isInteger=false, isLong=false, isNumber=false, isFloat=false, isDouble=false, isByteArray=false, isBinary=false, isFile=false, isBoolean=false, isDate=false, isDateTime=false, isUuid=false, isUri=false, isEmail=false, isFreeFormObject=false, isListContainer=false, isMapContainer=false, isEnum=false, isReadOnly=false, isWriteOnly=false, isNullable=false, isSelfReference=false, isCircularReference=false, _enum=null, allowableValues=null, items=null, mostInnerItems=null, vendorExtensions={}, hasValidation=false, isInherited=false, discriminatorValue='null', nameInCamelCase='AccessToken', nameInSnakeCase='ACCESS_TOKEN', enumName='null', maxItems=null, minItems=null, maxProperties=null, minProperties=null, uniqueItems=false, multipleOf=null, isXmlAttribute=false, xmlPrefix='null', xmlName='null', xmlNamespace='null', isXmlWrapped=false}, CodegenProperty{openApiType='integer', baseName='expires_in', complexType='null', getter='getExpiresIn', setter='setExpiresIn', description='null', dataType='int', datatypeWithEnum='int', dataFormat='null', name='expires_in', min='null', max='null', defaultValue='null', defaultValueWithParam=' = data.expires_in;', baseType='int', containerType='null', title='null', unescapedDescription='null', maxLength=null, minLength=null, pattern='null', example='56', jsonSchema='{
  "type" : "integer"
}', minimum='null', maximum='null', exclusiveMinimum=false, exclusiveMaximum=false, hasMore=true, required=false, deprecated=false, secondaryParam=false, hasMoreNonReadOnly=false, isPrimitiveType=true, isModel=false, isContainer=false, isString=false, isNumeric=true, isInteger=true, isLong=false, isNumber=false, isFloat=false, isDouble=false, isByteArray=false, isBinary=false, isFile=false, isBoolean=false, isDate=false, isDateTime=false, isUuid=false, isUri=false, isEmail=false, isFreeFormObject=false, isListContainer=false, isMapContainer=false, isEnum=false, isReadOnly=false, isWriteOnly=false, isNullable=false, isSelfReference=false, isCircularReference=false, _enum=null, allowableValues=null, items=null, mostInnerItems=null, vendorExtensions={}, hasValidation=false, isInherited=false, discriminatorValue='null', nameInCamelCase='ExpiresIn', nameInSnakeCase='EXPIRES_IN', enumName='null', maxItems=null, minItems=null, maxProperties=null, minProperties=null, uniqueItems=false, multipleOf=null, isXmlAttribute=false, xmlPrefix='null', xmlName='null', xmlNamespace='null', isXmlWrapped=false}, CodegenProperty{openApiType='string', baseName='token_type', complexType='null', getter='getTokenType', setter='setTokenType', description='null', dataType='str', datatypeWithEnum='str', dataFormat='null', name='token_type', min='null', max='null', defaultValue=''Bearer'', defaultValueWithParam=' = data.token_type;', baseType='str', containerType='null', title='null', unescapedDescription='null', maxLength=null, minLength=null, pattern='null', example=''0'', jsonSchema='{
  "type" : "string",
  "default" : "Bearer"
}', minimum='null', maximum='null', exclusiveMinimum=false, exclusiveMaximum=false, hasMore=true, required=false, deprecated=false, secondaryParam=false, hasMoreNonReadOnly=false, isPrimitiveType=true, isModel=false, isContainer=false, isString=true, isNumeric=false, isInteger=false, isLong=false, isNumber=false, isFloat=false, isDouble=false, isByteArray=false, isBinary=false, isFile=false, isBoolean=false, isDate=false, isDateTime=false, isUuid=false, isUri=false, isEmail=false, isFreeFormObject=false, isListContainer=false, isMapContainer=false, isEnum=false, isReadOnly=false, isWriteOnly=false, isNullable=false, isSelfReference=false, isCircularReference=false, _enum=null, allowableValues=null, items=null, mostInnerItems=null, vendorExtensions={}, hasValidation=false, isInherited=false, discriminatorValue='null', nameInCamelCase='TokenType', nameInSnakeCase='TOKEN_TYPE', enumName='null', maxItems=null, minItems=null, maxProperties=null, minProperties=null, uniqueItems=false, multipleOf=null, isXmlAttribute=false, xmlPrefix='null', xmlName='null', xmlNamespace='null', isXmlWrapped=false}, CodegenProperty{openApiType='string', baseName='refresh_token', complexType='null', getter='getRefreshToken', setter='setRefreshToken', description='null', dataType='str', datatypeWithEnum='str', dataFormat='null', name='refresh_token', min='null', max='null', defaultValue='null', defaultValueWithParam=' = data.refresh_token;', baseType='str', containerType='null', title='null', unescapedDescription='null', maxLength=null, minLength=null, pattern='null', example=''0'', jsonSchema='{
  "type" : "string"
}', minimum='null', maximum='null', exclusiveMinimum=false, exclusiveMaximum=false, hasMore=false, required=false, deprecated=false, secondaryParam=false, hasMoreNonReadOnly=false, isPrimitiveType=true, isModel=false, isContainer=false, isString=true, isNumeric=false, isInteger=false, isLong=false, isNumber=false, isFloat=false, isDouble=false, isByteArray=false, isBinary=false, isFile=false, isBoolean=false, isDate=false, isDateTime=false, isUuid=false, isUri=false, isEmail=false, isFreeFormObject=false, isListContainer=false, isMapContainer=false, isEnum=false, isReadOnly=false, isWriteOnly=false, isNullable=false, isSelfReference=false, isCircularReference=false, _enum=null, allowableValues=null, items=null, mostInnerItems=null, vendorExtensions={}, hasValidation=false, isInherited=false, discriminatorValue='null', nameInCamelCase='RefreshToken', nameInSnakeCase='REFRESH_TOKEN', enumName='null', maxItems=null, minItems=null, maxProperties=null, minProperties=null, uniqueItems=false, multipleOf=null, isXmlAttribute=false, xmlPrefix='null', xmlName='null', xmlNamespace='null', isXmlWrapped=false}], readOnlyVars=[], readWriteVars=[CodegenProperty{openApiType='string', baseName='access_token', complexType='null', getter='getAccessToken', setter='setAccessToken', description='null', dataType='str', datatypeWithEnum='str', dataFormat='null', name='access_token', min='null', max='null', defaultValue='null', defaultValueWithParam=' = data.access_token;', baseType='str', containerType='null', title='null', unescapedDescription='null', maxLength=null, minLength=null, pattern='null', example=''0'', jsonSchema='{
  "type" : "string"
}', minimum='null', maximum='null', exclusiveMinimum=false, exclusiveMaximum=false, hasMore=true, required=false, deprecated=false, secondaryParam=false, hasMoreNonReadOnly=false, isPrimitiveType=true, isModel=false, isContainer=false, isString=true, isNumeric=false, isInteger=false, isLong=false, isNumber=false, isFloat=false, isDouble=false, isByteArray=false, isBinary=false, isFile=false, isBoolean=false, isDate=false, isDateTime=false, isUuid=false, isUri=false, isEmail=false, isFreeFormObject=false, isListContainer=false, isMapContainer=false, isEnum=false, isReadOnly=false, isWriteOnly=false, isNullable=false, isSelfReference=false, isCircularReference=false, _enum=null, allowableValues=null, items=null, mostInnerItems=null, vendorExtensions={}, hasValidation=false, isInherited=false, discriminatorValue='null', nameInCamelCase='AccessToken', nameInSnakeCase='ACCESS_TOKEN', enumName='null', maxItems=null, minItems=null, maxProperties=null, minProperties=null, uniqueItems=false, multipleOf=null, isXmlAttribute=false, xmlPrefix='null', xmlName='null', xmlNamespace='null', isXmlWrapped=false}, CodegenProperty{openApiType='integer', baseName='expires_in', complexType='null', getter='getExpiresIn', setter='setExpiresIn', description='null', dataType='int', datatypeWithEnum='int', dataFormat='null', name='expires_in', min='null', max='null', defaultValue='null', defaultValueWithParam=' = data.expires_in;', baseType='int', containerType='null', title='null', unescapedDescription='null', maxLength=null, minLength=null, pattern='null', example='56', jsonSchema='{
  "type" : "integer"
}', minimum='null', maximum='null', exclusiveMinimum=false, exclusiveMaximum=false, hasMore=true, required=false, deprecated=false, secondaryParam=false, hasMoreNonReadOnly=false, isPrimitiveType=true, isModel=false, isContainer=false, isString=false, isNumeric=true, isInteger=true, isLong=false, isNumber=false, isFloat=false, isDouble=false, isByteArray=false, isBinary=false, isFile=false, isBoolean=false, isDate=false, isDateTime=false, isUuid=false, isUri=false, isEmail=false, isFreeFormObject=false, isListContainer=false, isMapContainer=false, isEnum=false, isReadOnly=false, isWriteOnly=false, isNullable=false, isSelfReference=false, isCircularReference=false, _enum=null, allowableValues=null, items=null, mostInnerItems=null, vendorExtensions={}, hasValidation=false, isInherited=false, discriminatorValue='null', nameInCamelCase='ExpiresIn', nameInSnakeCase='EXPIRES_IN', enumName='null', maxItems=null, minItems=null, maxProperties=null, minProperties=null, uniqueItems=false, multipleOf=null, isXmlAttribute=false, xmlPrefix='null', xmlName='null', xmlNamespace='null', isXmlWrapped=false}, CodegenProperty{openApiType='string', baseName='token_type', complexType='null', getter='getTokenType', setter='setTokenType', description='null', dataType='str', datatypeWithEnum='str', dataFormat='null', name='token_type', min='null', max='null', defaultValue=''Bearer'', defaultValueWithParam=' = data.token_type;', baseType='str', containerType='null', title='null', unescapedDescription='null', maxLength=null, minLength=null, pattern='null', example=''0'', jsonSchema='{
  "type" : "string",
  "default" : "Bearer"
}', minimum='null', maximum='null', exclusiveMinimum=false, exclusiveMaximum=false, hasMore=true, required=false, deprecated=false, secondaryParam=false, hasMoreNonReadOnly=false, isPrimitiveType=true, isModel=false, isContainer=false, isString=true, isNumeric=false, isInteger=false, isLong=false, isNumber=false, isFloat=false, isDouble=false, isByteArray=false, isBinary=false, isFile=false, isBoolean=false, isDate=false, isDateTime=false, isUuid=false, isUri=false, isEmail=false, isFreeFormObject=false, isListContainer=false, isMapContainer=false, isEnum=false, isReadOnly=false, isWriteOnly=false, isNullable=false, isSelfReference=false, isCircularReference=false, _enum=null, allowableValues=null, items=null, mostInnerItems=null, vendorExtensions={}, hasValidation=false, isInherited=false, discriminatorValue='null', nameInCamelCase='TokenType', nameInSnakeCase='TOKEN_TYPE', enumName='null', maxItems=null, minItems=null, maxProperties=null, minProperties=null, uniqueItems=false, multipleOf=null, isXmlAttribute=false, xmlPrefix='null', xmlName='null', xmlNamespace='null', isXmlWrapped=false}, CodegenProperty{openApiType='string', baseName='refresh_token', complexType='null', getter='getRefreshToken', setter='setRefreshToken', description='null', dataType='str', datatypeWithEnum='str', dataFormat='null', name='refresh_token', min='null', max='null', defaultValue='null', defaultValueWithParam=' = data.refresh_token;', baseType='str', containerType='null', title='null', unescapedDescription='null', maxLength=null, minLength=null, pattern='null', example=''0'', jsonSchema='{
  "type" : "string"
}', minimum='null', maximum='null', exclusiveMinimum=false, exclusiveMaximum=false, hasMore=false, required=false, deprecated=false, secondaryParam=false, hasMoreNonReadOnly=false, isPrimitiveType=true, isModel=false, isContainer=false, isString=true, isNumeric=false, isInteger=false, isLong=false, isNumber=false, isFloat=false, isDouble=false, isByteArray=false, isBinary=false, isFile=false, isBoolean=false, isDate=false, isDateTime=false, isUuid=false, isUri=false, isEmail=false, isFreeFormObject=false, isListContainer=false, isMapContainer=false, isEnum=false, isReadOnly=false, isWriteOnly=false, isNullable=false, isSelfReference=false, isCircularReference=false, _enum=null, allowableValues=null, items=null, mostInnerItems=null, vendorExtensions={}, hasValidation=false, isInherited=false, discriminatorValue='null', nameInCamelCase='RefreshToken', nameInSnakeCase='REFRESH_TOKEN', enumName='null', maxItems=null, minItems=null, maxProperties=null, minProperties=null, uniqueItems=false, multipleOf=null, isXmlAttribute=false, xmlPrefix='null', xmlName='null', xmlNamespace='null', isXmlWrapped=false}], parentVars=[], allowableValues=null, mandatory=[], allMandatory=[], imports=[], hasVars=true, emptyVars=false, hasMoreModels=false, hasEnums=false, isEnum=false, isNullable=false, hasRequired=false, hasOptional=true, isArrayModel=false, hasChildren=false, isMapModel=false, hasOnlyReadOnly=false, externalDocumentation=null, vendorExtensions={}, additionalPropertiesType='null', maxProperties=null, minProperties=null, uniqueItems=false, maxItems=null, minItems=null, maxLength=null, minLength=null, exclusiveMinimum=false, exclusiveMaximum=false, minimum='null', maximum='null', pattern='null', multipleOf='null'}
"""


class TokenResponseSchema(Schema):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    access_token = marshmallow.fields.String()

    expires_in = marshmallow.fields.Integer()

    token_type = marshmallow.fields.String()

    refresh_token = marshmallow.fields.String()

    @validates("access_token")
    def validates_access_token(self, access_token):
        pass

    @validates("expires_in")
    def validates_expires_in(self, expires_in):
        pass

    @validates("token_type")
    def validates_token_type(self, token_type):
        pass

    @validates("refresh_token")
    def validates_refresh_token(self, refresh_token):
        pass

    @post_load
    def post_load(self, data, **kwargs):
        config = Configuration()
        config.client_side_validation = False
        return TokenResponse(local_vars_configuration=config, **data)


class TokenResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'access_token': 'str',
        'expires_in': 'int',
        'token_type': 'str',
        'refresh_token': 'str'
    }

    attribute_map = {
        'access_token': 'access_token',
        'expires_in': 'expires_in',
        'token_type': 'token_type',
        'refresh_token': 'refresh_token'
    }

    def __init__(self, access_token=missing, expires_in=missing, token_type='Bearer', refresh_token=missing, local_vars_configuration=None):  # noqa: E501
        """TokenResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self.discriminator = None
        if self.local_vars_configuration.client_side_validation:
            validated = TokenResponseSchema().load({
                'access_token': access_token,
                'expires_in': expires_in,
                'token_type': token_type,
                'refresh_token': refresh_token
            })
            self.access_token = validated.access_token
            self.expires_in = validated.expires_in
            self.token_type = validated.token_type
            self.refresh_token = validated.refresh_token
        else:
            self.access_token = access_token
            self.expires_in = expires_in
            self.token_type = token_type
            self.refresh_token = refresh_token

    def to_dict(self):
        """Returns the model properties as a dict"""
        return TokenResponseSchema().dump(self)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TokenResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, TokenResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    TrueLayer Resource API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1.0
    Contact: rienafairefr@gmail.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import truelayer
from truelayer.models.api_response_card_transaction import APIResponseCardTransaction  # noqa: E501
from truelayer.rest import ApiException

class TestAPIResponseCardTransaction(unittest.TestCase):
    """APIResponseCardTransaction unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test APIResponseCardTransaction
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = truelayer.models.api_response_card_transaction.APIResponseCardTransaction()  # noqa: E501
        if include_optional :
            return APIResponseCardTransaction(
                results = [
                    truelayer.models.card_transaction.CardTransaction(
                        amount = 1.337, 
                        balance = truelayer.models.balance.Balance(
                            available = 1.337, 
                            currency = '0', 
                            current = 1.337, 
                            update_timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                        currency = '0', 
                        description = '0', 
                        meta = {
                            'key' : '0'
                            }, 
                        timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        transaction_id = '0', 
                        transaction_type = '0', )
                    ], 
                results_uri = '0', 
                status = 'Queued', 
                task_id = '0'
            )
        else :
            return APIResponseCardTransaction(
        )

    def testAPIResponseCardTransaction(self):
        """Test APIResponseCardTransaction"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
